@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.6.
+ This file is part of the QGLViewer library version 2.4.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -39,13 +39,10 @@ namespace qglviewer {
 	class MouseGrabber;
 }
 
-#if QT_VERSION >= 0x040000
-// Qt::ButtonState was split into Qt::KeyboardModifiers and Qt::MouseButtons in Qt 4.
-# define QtKeyboardModifiers Qt::KeyboardModifiers
-# define QtMouseButtons Qt::MouseButtons
-#else
-# define QtKeyboardModifiers Qt::ButtonState
-# define QtMouseButtons Qt::ButtonState
+#if QT_VERSION < 0x040000
+# define Qt::KeyboardModifiers Qt::ButtonState
+# define Qt::MouseButtons Qt::ButtonState
+# define Qt::WindowFlags Qt::WFlags
 #endif
 
 /*! \brief A versatile 3D OpenGL viewer based on QGLWidget.
@@ -78,15 +75,15 @@ public:
 	// Complete implementation is provided so that the constructor is defined with QT3_SUPPORT when .h is included.
 	// (Would not be available otherwise since lib is compiled without QT3_SUPPORT).
 #if QT_VERSION < 0x040000 || defined QT3_SUPPORT
-	explicit QGLViewer(QWidget* parent=NULL, const char* name=0, const QGLWidget* shareWidget=0, Qt::WFlags flags=0)
+    explicit QGLViewer(QWidget* parent=NULL, const char* name=0, const QGLWidget* shareWidget=0, Qt::WindowFlags flags=0)
 		: QGLWidget(parent, name, shareWidget, flags)
 	{ defaultConstructor(); }
 
-	explicit QGLViewer(const QGLFormat& format, QWidget* parent=0, const char* name=0, const QGLWidget* shareWidget=0,Qt::WFlags flags=0)
+    explicit QGLViewer(const QGLFormat& format, QWidget* parent=0, const char* name=0, const QGLWidget* shareWidget=0,Qt::WindowFlags flags=0)
 		: QGLWidget(format, parent, name, shareWidget, flags)
 	{ defaultConstructor(); }
 
-	QGLViewer(QGLContext* context, QWidget* parent, const char* name=0, const QGLWidget* shareWidget=0, Qt::WFlags flags=0)
+    QGLViewer(QGLContext* context, QWidget* parent, const char* name=0, const QGLWidget* shareWidget=0, Qt::WindowFlags flags=0)
 # if QT_VERSION >= 0x030200
 		: QGLWidget(context, parent, name, shareWidget, flags) {
 # else
@@ -96,12 +93,12 @@ public:
 			// MOC_SKIP_END
 # endif
 			defaultConstructor(); }
-#endif
 
-#if QT_VERSION >= 0x040000
-	explicit QGLViewer(QWidget* parent=0, const QGLWidget* shareWidget=0, Qt::WFlags flags=0);
-	explicit QGLViewer(QGLContext *context, QWidget* parent=0, const QGLWidget* shareWidget=0, Qt::WFlags flags=0);
-	explicit QGLViewer(const QGLFormat& format, QWidget* parent=0, const QGLWidget* shareWidget=0, Qt::WFlags flags=0);
+#else
+
+    explicit QGLViewer(QWidget* parent=0, const QGLWidget* shareWidget=0, Qt::WindowFlags flags=0);
+    explicit QGLViewer(QGLContext *context, QWidget* parent=0, const QGLWidget* shareWidget=0, Qt::WindowFlags flags=0);
+    explicit QGLViewer(const QGLFormat& format, QWidget* parent=0, const QGLWidget* shareWidget=0, Qt::WindowFlags flags=0);
 #endif
 
 	virtual ~QGLViewer();
@@ -249,8 +246,8 @@ public:
 
 		This is equivalent to:
 		\code
-		setSceneCenter((m+M)/2.0);
-		setSceneRadius(0.5*(M-m).norm());
+		setSceneCenter((min+max) / 2.0);
+		setSceneRadius((max-min).norm() / 2.0);
 		\endcode */
 		void setSceneBoundingBox(const qglviewer::Vec& min, const qglviewer::Vec& max) { camera()->setSceneBoundingBox(min,max); }
 
@@ -362,7 +359,6 @@ public:
 	See Camera::loadProjectionMatrixStereo() and Camera::loadModelViewMatrixStereo().
 
 	The stereo parameters are defined by the camera(). See qglviewer::Camera::setIODistance(),
-	qglviewer::Camera::setPhysicalDistanceToScreen(),
 	qglviewer::Camera::setPhysicalScreenWidth() and
 	qglviewer::Camera::setFocusDistance(). */
 	bool displaysInStereo() const { return stereo_; }
@@ -932,22 +928,22 @@ protected:
 		MOVE_CAMERA_LEFT, MOVE_CAMERA_RIGHT, MOVE_CAMERA_UP, MOVE_CAMERA_DOWN,
 		INCREASE_FLYSPEED, DECREASE_FLYSPEED, SNAPSHOT_TO_CLIPBOARD };
 public:
-	int shortcut(KeyboardAction action) const;
+    unsigned int shortcut(KeyboardAction action) const;
 #ifndef DOXYGEN
 	// QGLViewer 1.x
 	int keyboardAccelerator(KeyboardAction action) const;
 	Qt::Key keyFrameKey(int index) const;
-	QtKeyboardModifiers playKeyFramePathStateKey() const;
+    Qt::KeyboardModifiers playKeyFramePathStateKey() const;
 	// QGLViewer 2.0 without Qt4 support
-	QtKeyboardModifiers addKeyFrameStateKey() const;
-	QtKeyboardModifiers playPathStateKey() const;
+    Qt::KeyboardModifiers addKeyFrameStateKey() const;
+    Qt::KeyboardModifiers playPathStateKey() const;
 #endif
 	Qt::Key pathKey(int index) const;
-	QtKeyboardModifiers addKeyFrameKeyboardModifiers() const;
-	QtKeyboardModifiers playPathKeyboardModifiers() const;
+    Qt::KeyboardModifiers addKeyFrameKeyboardModifiers() const;
+    Qt::KeyboardModifiers playPathKeyboardModifiers() const;
 
 	public Q_SLOTS:
-		void setShortcut(KeyboardAction action, int key);
+        void setShortcut(KeyboardAction action, unsigned int key);
 #ifndef DOXYGEN
 		void setKeyboardAccelerator(KeyboardAction action, int key);
 #endif
@@ -963,8 +959,8 @@ public:
 		virtual void setAddKeyFrameStateKey(int buttonState);
 #endif
 		virtual void setPathKey(int key, int index = 0);
-		virtual void setPlayPathKeyboardModifiers(QtKeyboardModifiers modifiers);
-		virtual void setAddKeyFrameKeyboardModifiers(QtKeyboardModifiers modifiers);
+        virtual void setPlayPathKeyboardModifiers(Qt::KeyboardModifiers modifiers);
+        virtual void setAddKeyFrameKeyboardModifiers(Qt::KeyboardModifiers modifiers);
 		//@}
 
 
@@ -1007,29 +1003,29 @@ public:
 	MouseAction mouseAction(int state) const;
 	int mouseHandler(int state) const;
 	int mouseButtonState(MouseHandler handler, MouseAction action, bool withConstraint=true) const;
-	ClickAction clickAction(int state, bool doubleClick, QtMouseButtons buttonsBefore) const;
-	void getClickButtonState(ClickAction action, int& state, bool& doubleClick, QtMouseButtons& buttonsBefore) const;
+    ClickAction clickAction(int state, bool doubleClick, Qt::MouseButtons buttonsBefore) const;
+    void getClickButtonState(ClickAction action, int& state, bool& doubleClick, Qt::MouseButtons& buttonsBefore) const;
 
-	MouseAction wheelAction(QtKeyboardModifiers modifiers) const;
-	int wheelHandler(QtKeyboardModifiers modifiers) const;
+    MouseAction wheelAction(Qt::KeyboardModifiers modifiers) const;
+    int wheelHandler(Qt::KeyboardModifiers modifiers) const;
 	int wheelButtonState(MouseHandler handler, MouseAction action, bool withConstraint=true) const;
 
-	public Q_SLOTS:
-		void setMouseBinding(int state, MouseHandler handler, MouseAction action, bool withConstraint=true);
+public Q_SLOTS:
+    void setMouseBinding(int state, MouseHandler handler, MouseAction action, bool withConstraint=true);
 #if QT_VERSION < 0x030000
-		// Two slots cannot have the same name or two default parameters with Qt 2.3.
+    // Two slots cannot have the same name or two default parameters with Qt 2.3.
 public:
 #endif
-	void setMouseBinding(int state, ClickAction action, bool doubleClick=false, QtMouseButtons buttonsBefore=Qt::NoButton);
-	void setMouseBindingDescription(int state, QString description, bool doubleClick=false, QtMouseButtons buttonsBefore=Qt::NoButton);
+    void setMouseBinding(int state, ClickAction action, bool doubleClick=false, Qt::MouseButtons buttonsBefore=Qt::NoButton);
 #if QT_VERSION < 0x030000
-	public Q_SLOTS:
+public Q_SLOTS:
 #endif
-		void setWheelBinding(QtKeyboardModifiers modifiers, MouseHandler handler, MouseAction action, bool withConstraint=true);
-		void setHandlerKeyboardModifiers(MouseHandler handler, QtKeyboardModifiers modifiers);
+    void setMouseBindingDescription(int state, QString description, bool doubleClick=false, Qt::MouseButtons buttonsBefore=Qt::NoButton);
+    void setWheelBinding(Qt::KeyboardModifiers modifiers, MouseHandler handler, MouseAction action, bool withConstraint=true);
+    void setHandlerKeyboardModifiers(MouseHandler handler, Qt::KeyboardModifiers modifiers);
 #ifndef DOXYGEN
-		void setHandlerStateKey(MouseHandler handler, int buttonState);
-		void setMouseStateKey(MouseHandler handler, int buttonState);
+    void setHandlerStateKey(MouseHandler handler, int buttonState);
+    void setMouseStateKey(MouseHandler handler, int buttonState);
 #endif
 
 private:
@@ -1076,18 +1072,17 @@ private:
 	/*! @name QGLViewer pool */
 	//@{
 public:
-	/*! Returns a \c QList (see Qt documentation) that contains pointers to all the created
-	QGLViewers. Note that this list may contain \c NULL pointers if the associated viewer has been deleted.
+	/*! Returns a \c QList that contains pointers to all the created QGLViewers.
+        Note that this list may contain \c NULL pointers if the associated viewer has been deleted.
 
-	Can be useful to apply a method or to connect a signal to all the viewers.
+	Can be useful to apply a method or to connect a signal to all the viewers:
+        \code
+	foreach (QGLViewer* viewer, QGLViewer::QGLViewerPool())
+ 	  connect(myObject, SIGNAL(IHaveChangedSignal()), viewer, SLOT(updateGL()));
+	\endcode
 
 	\attention With Qt version 3, this method returns a \c QPtrList instead. Use a \c QPtrListIterator
-	to iterate on the list:
-	\code
-	QPtrListIterator<QGLViewer> it(QGLViewer::QGLViewerPool());
-	for (QGLViewer* viewer; (viewer = it.current()) != NULL; ++it)
-	connect(myObject, SIGNAL(mySignal), viewer, SLOT(updateGL()));
-	\endcode */
+	to iterate on the list instead.*/
 #if QT_VERSION >= 0x040000
 	static const QList<QGLViewer*>& QGLViewerPool() { return QGLViewer::QGLViewerPool_; };
 #else
@@ -1099,12 +1094,13 @@ public:
 	can be used to identify the different created QGLViewers (see stateFileName() for an application
 	example).
 
-	When a QGLViewer is deleted, the following QGLViewers' indexes are shifted down. Returns -1 if the
-	QGLViewer could not be found (which should not be possible). */
+	When a QGLViewer is deleted, the QGLViewers' indexes are preserved and NULL is set for that index.
+        When a QGLViewer is created, it is placed in the first available position in that list.
+        Returns -1 if the QGLViewer could not be found (which should not be possible). */
 #if QT_VERSION >= 0x040000
 	static int QGLViewerIndex(const QGLViewer* const viewer) { return QGLViewer::QGLViewerPool_.indexOf(const_cast<QGLViewer*>(viewer)); };
 #else
-	static int QGLViewerIndex(const QGLViewer* const viewer) { return QGLViewer::QGLViewerPool_.find(viewer); };
+	static int QGLViewerIndex(const QGLViewer* const viewer) { return QGLViewer::QGLViewerPool_.findRef(viewer); };
 #endif
 	//@}
 
@@ -1194,12 +1190,12 @@ private:
 	void setDefaultShortcuts();
 	QString cameraPathKeysString() const;
 	QMap<KeyboardAction, QString> keyboardActionDescription_;
-	QMap<KeyboardAction, int> keyboardBinding_;
-	QMap<int, QString> keyDescription_;
+    QMap<KeyboardAction, unsigned int> keyboardBinding_;
+    QMap<int, QString> keyDescription_;
 
 	// K e y   F r a m e s   s h o r t c u t s
 	QMap<Qt::Key, int> pathIndex_;
-	QtKeyboardModifiers addKeyFrameKeyboardModifiers_, playPathKeyboardModifiers_;
+    Qt::KeyboardModifiers addKeyFrameKeyboardModifiers_, playPathKeyboardModifiers_;
 
 	// B u f f e r   T e x t u r e
 	GLuint bufferTextureId_;
@@ -1218,10 +1214,10 @@ private:
 
 	// C l i c k   a c t i o n s
 	struct ClickActionPrivate {
-		QtKeyboardModifiers modifiers;
-		QtMouseButtons button;
+        Qt::KeyboardModifiers modifiers;
+        Qt::MouseButtons button;
 		bool doubleClick;
-		QtMouseButtons buttonsBefore; // only defined when doubleClick is true
+        Qt::MouseButtons buttonsBefore; // only defined when doubleClick is true
 
 		// This sort order in used in mouseString() to displays sorted mouse bindings
 		bool operator<(const ClickActionPrivate& cap) const
@@ -1246,7 +1242,7 @@ private:
 	void setDefaultMouseBindings();
 	void performClickAction(ClickAction ca, const QMouseEvent* const e);
 	QMap<int, MouseActionPrivate> mouseBinding_;
-	QMap<QtKeyboardModifiers, MouseActionPrivate> wheelBinding_;
+    QMap<Qt::KeyboardModifiers, MouseActionPrivate> wheelBinding_;
 	QMap<ClickActionPrivate, ClickAction> clickBinding_;
 
 	// S n a p s h o t s
