@@ -17,7 +17,7 @@ var searchData=
   ['selectedname',['selectedName',['../classQGLViewer.html#a0015a8bc683c3a1483c5ad638550bdde',1,'QGLViewer']]],
   ['selectregionheight',['selectRegionHeight',['../classQGLViewer.html#adb0b15577ca9bcabc99c78601cfce59f',1,'QGLViewer']]],
   ['selectregionwidth',['selectRegionWidth',['../classQGLViewer.html#a16ad2d80aa574d32ae8237f56cfd7e06',1,'QGLViewer']]],
-  ['setaddkeyframekeyboardmodifiers',['setAddKeyFrameKeyboardModifiers',['../classQGLViewer.html#aa9a5108680fffd096a3e086a3b8b45d4',1,'QGLViewer']]],
+  ['setaddkeyframekeyboardmodifiers',['setAddKeyFrameKeyboardModifiers',['../classQGLViewer.html#afe04d1c918e50f6b4db5f7b6c7b80219',1,'QGLViewer']]],
   ['setanimationperiod',['setAnimationPeriod',['../classQGLViewer.html#aa37d4e0afe6a47e8f4f828ed41072176',1,'QGLViewer']]],
   ['setaspectratio',['setAspectRatio',['../classqglviewer_1_1Camera.html#a5b191e9b12b704a05302b5d922792e9c',1,'qglviewer::Camera']]],
   ['setautobufferswap',['setAutoBufferSwap',['../classQGLViewer.html#ad95e0ffd255bcc1fb69c9213d8d8b017',1,'QGLViewer']]],
@@ -43,7 +43,7 @@ var searchData=
   ['setfullscreen',['setFullScreen',['../classQGLViewer.html#a7e021e15180ba348e90c955bdd28b1a4',1,'QGLViewer']]],
   ['setgrabsmouse',['setGrabsMouse',['../classqglviewer_1_1MouseGrabber.html#a9ecea0a9f8ce1b2d92bbd1dd6bdcd4f9',1,'qglviewer::MouseGrabber']]],
   ['setgridisdrawn',['setGridIsDrawn',['../classQGLViewer.html#ae9dd114195dfdf82e23b5754b7c161de',1,'QGLViewer']]],
-  ['sethandlerkeyboardmodifiers',['setHandlerKeyboardModifiers',['../classQGLViewer.html#a0f709bcb22461a4e9df78de2821b9c80',1,'QGLViewer']]],
+  ['sethandlerkeyboardmodifiers',['setHandlerKeyboardModifiers',['../classQGLViewer.html#a721cb18512f6fa7bd664ac0d3453800c',1,'QGLViewer']]],
   ['sethorizontalfieldofview',['setHorizontalFieldOfView',['../classqglviewer_1_1Camera.html#a017ace2ed5f67b6aeaef5c9a47b5f014',1,'qglviewer::Camera']]],
   ['setinterpolationperiod',['setInterpolationPeriod',['../classqglviewer_1_1KeyFrameInterpolator.html#a9763e647346a8bee885517d9985173fd',1,'qglviewer::KeyFrameInterpolator']]],
   ['setinterpolationspeed',['setInterpolationSpeed',['../classqglviewer_1_1KeyFrameInterpolator.html#a3cc64e95e1b8dfda110bcf3d033ecf2d',1,'qglviewer::KeyFrameInterpolator']]],
@@ -53,8 +53,8 @@ var searchData=
   ['setkeyframeinterpolator',['setKeyFrameInterpolator',['../classqglviewer_1_1Camera.html#a049b63c8c9ef48e24446ce44a3bd32b5',1,'qglviewer::Camera']]],
   ['setloopinterpolation',['setLoopInterpolation',['../classqglviewer_1_1KeyFrameInterpolator.html#a31a491ac2ac016298cbd1c66f07be6dd',1,'qglviewer::KeyFrameInterpolator']]],
   ['setmanipulatedframe',['setManipulatedFrame',['../classQGLViewer.html#ac6964ec1ebb2f42464313e0c43e767a3',1,'QGLViewer']]],
-  ['setmousebinding',['setMouseBinding',['../classQGLViewer.html#a218f2279fd64d5841b5ae2fc67d74274',1,'QGLViewer::setMouseBinding(int state, MouseHandler handler, MouseAction action, bool withConstraint=true)'],['../classQGLViewer.html#a3225418600cc93fb968e11ce195bee2d',1,'QGLViewer::setMouseBinding(int state, ClickAction action, bool doubleClick=false, QtMouseButtons buttonsBefore=Qt::NoButton)']]],
-  ['setmousebindingdescription',['setMouseBindingDescription',['../classQGLViewer.html#a2e1e005bde20f65b7269e2dd4e978306',1,'QGLViewer']]],
+  ['setmousebinding',['setMouseBinding',['../classQGLViewer.html#a218f2279fd64d5841b5ae2fc67d74274',1,'QGLViewer::setMouseBinding(int state, MouseHandler handler, MouseAction action, bool withConstraint=true)'],['../classQGLViewer.html#a79898ef0287beb4df60860145a28f904',1,'QGLViewer::setMouseBinding(int state, ClickAction action, bool doubleClick=false, Qt::MouseButtons buttonsBefore=Qt::NoButton)']]],
+  ['setmousebindingdescription',['setMouseBindingDescription',['../classQGLViewer.html#aa43a723e1a4505a5b4d39ea60e4f2212',1,'QGLViewer']]],
   ['setmousegrabber',['setMouseGrabber',['../classQGLViewer.html#a993285ef8a16ccbdc5d57a1264212712',1,'QGLViewer']]],
   ['setmousegrabberisenabled',['setMouseGrabberIsEnabled',['../classQGLViewer.html#a3f0b956f948f469c095ff3c2c1b73494',1,'QGLViewer']]],
   ['setmousetracking',['setMouseTracking',['../classQGLViewer.html#acf0a4ee197fe91b8c07dd74cad1aafaa',1,'QGLViewer']]],
@@ -62,7 +62,7 @@ var searchData=
   ['setorientationwithconstraint',['setOrientationWithConstraint',['../classqglviewer_1_1Frame.html#a8b69106a268d78daf27d32854d455da4',1,'qglviewer::Frame']]],
   ['setpathkey',['setPathKey',['../classQGLViewer.html#ada7e68536b6593f8a8bde9a746c99c13',1,'QGLViewer']]],
   ['setphysicalscreenwidth',['setPhysicalScreenWidth',['../classqglviewer_1_1Camera.html#a34911cda1cc1bc13336024c844ff4401',1,'qglviewer::Camera']]],
-  ['setplaypathkeyboardmodifiers',['setPlayPathKeyboardModifiers',['../classQGLViewer.html#a7c941d66cf641971ef0bb99e998290dc',1,'QGLViewer']]],
+  ['setplaypathkeyboardmodifiers',['setPlayPathKeyboardModifiers',['../classQGLViewer.html#ab8e16934baadfe8db4f68dedc98075a1',1,'QGLViewer']]],
   ['setposition',['setPosition',['../classqglviewer_1_1Camera.html#a212edb01759f542f356c5d62e4a3f821',1,'qglviewer::Camera::setPosition()'],['../classqglviewer_1_1Frame.html#a24f5da9b3f4bf4e71dfad7a74a932e52',1,'qglviewer::Frame::setPosition(const Vec &amp;position)'],['../classqglviewer_1_1Frame.html#aff7308b903966afc6c87b5cd766a9083',1,'qglviewer::Frame::setPosition(float x, float y, float z)']]],
   ['setpositionandorientation',['setPositionAndOrientation',['../classqglviewer_1_1Frame.html#a47912d16be51eb85d68d3dcb4a4fb087',1,'qglviewer::Frame']]],
   ['setpositionandorientationwithconstraint',['setPositionAndOrientationWithConstraint',['../classqglviewer_1_1Frame.html#a8501c5582c1aa2a82a929ce36439ab3a',1,'qglviewer::Frame']]],
@@ -85,7 +85,7 @@ var searchData=
   ['setselectedname',['setSelectedName',['../classQGLViewer.html#aeaa1327270d0bcdf991874e7d741afd5',1,'QGLViewer']]],
   ['setselectregionheight',['setSelectRegionHeight',['../classQGLViewer.html#ae830757057c41db506410fd3c332d7dd',1,'QGLViewer']]],
   ['setselectregionwidth',['setSelectRegionWidth',['../classQGLViewer.html#a0bfc48a72feefc6c90bd187280853911',1,'QGLViewer']]],
-  ['setshortcut',['setShortcut',['../classQGLViewer.html#a910dc7fa27de6f4d8e9e8ed7fa7a1667',1,'QGLViewer']]],
+  ['setshortcut',['setShortcut',['../classQGLViewer.html#a34d76d224c67a0fdae03f0d921bf3330',1,'QGLViewer']]],
   ['setsnapshotcounter',['setSnapshotCounter',['../classQGLViewer.html#afeb307bbd1a56cdfb3749f699d4af03c',1,'QGLViewer']]],
   ['setsnapshotfilename',['setSnapshotFileName',['../classQGLViewer.html#aa15be68d137eca013942eae69e40e0ee',1,'QGLViewer']]],
   ['setsnapshotformat',['setSnapshotFormat',['../classQGLViewer.html#a82043998256d08163f79ceee83278e14',1,'QGLViewer']]],
@@ -108,11 +108,11 @@ var searchData=
   ['setupvector',['setUpVector',['../classqglviewer_1_1Camera.html#ab442b71a46297223ae12b163653eeb7e',1,'qglviewer::Camera']]],
   ['setvalue',['setValue',['../classqglviewer_1_1Quaternion.html#abe7dd94e4fb48e0c8e0d994cac84064a',1,'qglviewer::Quaternion::setValue()'],['../classqglviewer_1_1Vec.html#ab4794e5d9a45a51ab239593116c480aa',1,'qglviewer::Vec::setValue()']]],
   ['setviewdirection',['setViewDirection',['../classqglviewer_1_1Camera.html#a066c4058970a008d0d0a8ff442d117f6',1,'qglviewer::Camera']]],
-  ['setwheelbinding',['setWheelBinding',['../classQGLViewer.html#a4198b3b668c342e39752bade04f78c64',1,'QGLViewer']]],
+  ['setwheelbinding',['setWheelBinding',['../classQGLViewer.html#a277f432be05de69ae2df05eac8951ad2',1,'QGLViewer']]],
   ['setwheelsensitivity',['setWheelSensitivity',['../classqglviewer_1_1ManipulatedFrame.html#afd6cb097279239492a3401893d317499',1,'qglviewer::ManipulatedFrame']]],
   ['setzclippingcoefficient',['setZClippingCoefficient',['../classqglviewer_1_1Camera.html#a62ab18396bd8c212ec7b90dc156b59d7',1,'qglviewer::Camera']]],
   ['setznearcoefficient',['setZNearCoefficient',['../classqglviewer_1_1Camera.html#a1d478610f928ecc4597c56d677d908b5',1,'qglviewer::Camera']]],
-  ['shortcut',['shortcut',['../classQGLViewer.html#ab6dd5b47ea7d89e1f86c05c58d25c11d',1,'QGLViewer']]],
+  ['shortcut',['shortcut',['../classQGLViewer.html#af8f502daf9ffa61c8904f891c843e994',1,'QGLViewer']]],
   ['show_5fentire_5fscene',['SHOW_ENTIRE_SCENE',['../classQGLViewer.html#a85fe75121d351785616b75b2c5661d8fa3f717d1605f3ca83254beb93ea399ddc',1,'QGLViewer']]],
   ['showentirescene',['showEntireScene',['../classqglviewer_1_1Camera.html#ada8dd7d2346ebf46ed1f9822a8418df2',1,'qglviewer::Camera::showEntireScene()'],['../classQGLViewer.html#ada8dd7d2346ebf46ed1f9822a8418df2',1,'QGLViewer::showEntireScene()']]],
   ['sizehint',['sizeHint',['../classQGLViewer.html#ad8288a17cf54658f1ce1c0db9e97dc8a',1,'QGLViewer']]],
