@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2011 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.17.
+ This file is part of the QGLViewer library version 2.4.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -26,7 +26,7 @@
 #include <qglobal.h>
 
 #if QT_VERSION >= 0x040000
-# include "ui_dvonnwindow.Qt4.h"
+# include "ui_dvonnwindow.h"
   class DvonnWindow : public QMainWindow, public Ui::DvonnWindow
   {
   public:
