@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2011 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.17.
+ This file is part of the QGLViewer library version 2.4.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -27,11 +27,11 @@ bool Jeu::needDrawing(int i)
 
 void Jeu::placePiece(int select, Piece *p)
 {
-  // on verifie que la piece n'ai pas t dja place autre part
+  // on verifie que la piece n'ai pas été déja placée autre part
   for(int i=0; i<16; i++)
     if(tab[i].piece==p) {
-      if(i==select) return; // la piece a dja t place au bon endroit
-      // si oui, on l'enlve
+      if(i==select) return; // la piece a déja été placée au bon endroit
+      // si oui, on l'enlève
       tab[i].empty=true;
       tab[i].piece=NULL;
     }
@@ -40,7 +40,7 @@ void Jeu::placePiece(int select, Piece *p)
   tab[select].piece=p;
 }
 
-// Vrai ssi les 4 pieces ont unbe caractristique commune
+// Vrai ssi les 4 pieces ont unbe caractéristique commune
 bool Jeu::caracCommune(Piece* pieces[4])
 {
   for (int i=0; i<4; ++i)
@@ -68,7 +68,7 @@ bool Jeu::caracCommune(Piece* pieces[4])
   return false;
 }
 
-// Analyse si un alignement a t effectu
+// Analyse si un alignement a été effectué
 bool Jeu::analyze()
 {
   Piece* pieces[4];
