@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2011 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.17.
+ This file is part of the QGLViewer library version 2.4.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,10 +22,16 @@
 
 #include "piece.h"
 
+#ifdef Q_OS_MAC
+# include <OpenGL/glu.h>
+#else
+# include <GL/glu.h>
+#endif
+
 SetOfPiece::SetOfPiece()
 {
   selected=-1;
-  // on cre et place chaque piece
+  // on crée et place chaque piece
   for(int i=0; i<16; i++)
     tab[i]=new Piece(i, i/8, (i/4)%2, (i/2)%2, i%2, (i%4)*4.5, (i/4)*4.5 );
 }
@@ -56,7 +62,7 @@ void SetOfPiece::setTexture(GLuint texture)
 
 void SetOfPiece::placeSelectedPiece(int select)
 {
-  // Si aucun objet n'est selectionn, on ne fait rien
+  // Si aucun objet n'est selectionné, on ne fait rien
   if(selected==-1) return;
   tab[selected]->setFenetre(true);
   tab[selected]->setPos((select%4)*3.5+3.7, (select/4)*3.5+3.7);
@@ -74,7 +80,7 @@ Piece::Piece(int i, bool c, bool s, bool f, bool t, double x, double y) : id(i),
 {
   // La fenetre est au debut, celle de selection
   fenetre=false;
-  // La piece n'est pas selectionne
+  // La piece n'est pas selectionnée
   selected=false;
   // On initialise les parametres de couleur
     for (int i=0; i<3; ++i)
@@ -87,7 +93,7 @@ Piece::Piece(int i, bool c, bool s, bool f, bool t, double x, double y) : id(i),
 
 void Piece::paint(bool fen)
 {
-  // Si l'objet ne doit pas etre affich dans la fenetre, on sort
+  // Si l'objet ne doit pas etre affiché dans la fenetre, on sort
   if(fenetre!=fen) return;
   // On place l'objet au bon endroit
   glPushMatrix();
