@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2011 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.17.
+ This file is part of the QGLViewer library version 2.4.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -31,7 +31,6 @@
 #include <qmessagebox.h>
 #include <qpushbutton.h>
 #include <qwidget.h>
-#include <qmime.h>
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qdialog.h>
@@ -70,7 +69,7 @@ Quarto::Quarto(QWidget* parent)
   MainHLayout = new QHBoxLayout( NULL );
 
   GLFrameJeu = new QFrame( centralWidget() );
-  GLFrameJeu->setMouseTracking( TRUE );
+  GLFrameJeu->setMouseTracking( true );
   GLFrameJeu->setFrameShape( QFrame::StyledPanel );
   GLFrameJeu->setFrameShadow( QFrame::Raised );
   GLFrameJeu->setFrameStyle( QFrame::Sunken | QFrame::Panel );
@@ -121,7 +120,7 @@ Quarto::Quarto(QWidget* parent)
   // Fenetre de vue des pieces //
   //##########################//
   GLFramePieces = new QFrame( centralWidget() );
-  GLFramePieces->setMouseTracking( TRUE );
+  GLFramePieces->setMouseTracking( true );
   GLFramePieces->setFrameShape( QFrame::StyledPanel );
   GLFramePieces->setFrameShadow( QFrame::Raised );
   GLFramePieces->setFrameStyle( QFrame::Sunken | QFrame::Panel );
