@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.6.
+ This file is part of the QGLViewer library version 2.4.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,7 +23,7 @@
 #include <qapplication.h>
 
 #if QT_VERSION >= 0x040000
-# include "ui_viewerInterface.Qt4.h"
+# include "ui_viewerInterface.h"
   class ViewerInterface : public QDialog, public Ui::Dialog
   {
   public:
